@@ -147,9 +147,9 @@ static int dhcp_recv(struct netdev *dev)
 	};
 	int ret;
 
-	ret = packet_recv(iov, 3);
-	if (ret == 0)
-		return -1;
+	ret = packet_recv(dev, iov, 3);
+	if (ret <= 0)
+		return ret;
 
 	dprintf("\n   dhcp xid %08x ", dev->bootp.xid);
 
